@@ -1,7 +1,7 @@
 #! /usr/bin/python
 # -*- coding: UTF-8 -*-
 
-#  Copyright 2013-2018 Luiko Czub, TestLink-API-Python-client developers
+#  Copyright 2013-2019 Luiko Czub, TestLink-API-Python-client developers
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -18,8 +18,9 @@
 # ------------------------------------------------------------------------
 
 import sys, os.path
-IS_PY3 = sys.version_info[0] < 3
-if IS_PY3:
+IS_PY3 = sys.version_info[0] > 2
+if not IS_PY3:
+    # importing required py2 modules
     import xmlrpclib
     # in py 3 encodestring is deprecated and an alias for encodebytes
     # see issue #39 and compare py2 py3 doc 
@@ -27,6 +28,7 @@ if IS_PY3:
     # https://docs.python.org/3/library/base64.html#base64.encodebytes
     from base64 import encodestring as encodebytes
 else:
+    # importing required py3 modules
     import xmlrpc.client as xmlrpclib
     from base64 import encodebytes
     
@@ -488,6 +490,8 @@ TL version >= 1.9.11
 #    *                     'full': (default) get summary,steps,expected_results,test suite name
 #    *                     'simple':
 #    *                     'details':
+#    * @param array $args["customfields"]
+#    *             - optional can be a boolean or an array with the requested fields
 #    * @return mixed $resultInfo
 #    *
 #    * @internal revisions
@@ -501,7 +505,8 @@ TL version >= 1.9.11
     @decoMakerApiCallWithArgs(['testplanid'], 
                 ['buildid', 'platformid', 
                  'testcaseid', 'keywordid', 'keywords', 'executed', 'assignedto', 
-                 'executestatus', 'executiontype', 'getstepinfo', 'details'])
+                 'executestatus', 'executiontype', 'getstepinfo', 'details',
+                 'customfields'])
     def getTestCasesForTestPlan(self):
         """ List test cases linked to a test plan
         
@@ -593,10 +598,40 @@ TL version >= 1.9.11
         b) requirements with ID 6735 and 6737 of requirement spec 6733
         """
 
+#     /**
+#      * Gets attachments for specified test case VERSION.
+#      * The attachment file content is Base64 encoded. To save the file to disk in client,
+#      * Base64 decode the content and write file in binary mode.
+#      *
+#      * @param struct $args
+#      * @param string $args["devKey"]
+#      *            Developer key
+#      * @param int $args["testcaseid"]:
+#      *            optional, if does not is present
+#      *            testcaseexternalid must be present
+#      *
+#      * @param int $args["version"]:
+#      *            optional, if not present, the latest version will be used
+#      *
+#      * @param int $args["testcaseexternalid"]:
+#      *            optional, if does not is present
+#      *            testcaseid must be present
+#      *
+#      * @return mixed $resultInfo
+#      */
+#     public function getTestCaseAttachments($args) {
+
     @decoApiCallAddDevKey               
-    @decoMakerApiCallWithArgs([], ['testcaseid', 'testcaseexternalid'])
+    @decoMakerApiCallWithArgs([], ['testcaseid', 'version', 
+                                   'testcaseexternalid'])
     def getTestCaseAttachments(self):
         """ Gets attachments for specified test case.
+        
+        args variations: testcaseid - testcaseexternalid
+        
+        version - optional, if not present, the latest test case version 
+                  will be used
+        
         The attachment file content is Base64 encoded. To save the file to disk 
         in client, Base64 decode the content and write file in binary mode.  """
 
@@ -806,14 +841,44 @@ TL version >= 1.9.11
         ATTACHMENTFILE, but user could overwrite it, if user want to store the
         attachment with a different name 
         """
+#     /**
+#      * Uploads an attachment for a Test Case.
+#      *
+#      * The attachment content must be Base64 encoded by the client before sending it.
+#      *
+#      * @param struct $args
+#      * @param string $args["devKey"]
+#      *            Developer key
+#      * @param int $args["testcaseid"]
+#      *            Test Case INTERNAL ID
+#      * @param int $args["version"]
+#      *            version number
+#      *
+#      * @param string $args["title"]
+#      *           (Optional) The title of the Attachment
+#      * @param string $args["description"]
+#      *           (Optional) The description of the Attachment
+#      * @param string $args["filename"]
+#      *            The file name of the Attachment(e.g.:notes.txt)
+#      * @param string $args["filetype"]
+#      *            The file type of the Attachment(e.g.: text/plain)
+#      * @param string $args["content"]
+#      *            The content(Base64 encoded) of the Attachment
+#      *
+#      * @return mixed $resultInfo an array containing the fk_id, fk_table, title,
+#      *         description, file_name, file_size and file_type. If any errors occur it
+#      *         returns the erros map.
+#      */
+#     public function uploadTestCaseAttachment($args) {
 
     @decoApiCallAddAttachment            
-    @decoMakerApiCallWithArgs(['testcaseid'], 
+    @decoMakerApiCallWithArgs(['testcaseid', 'version'], 
                     ['title', 'description', 'filename', 'filetype', 'content'])
     def uploadTestCaseAttachment(self):
         """ Uploads an attachment for a Test Case.
         
         testcaseid - Test Case INTERNAL ID
+        version    - Test Case version number
         
         mandatory non api args: attachmentfile
         - python file descriptor pointing to the file
