@@ -1,7 +1,7 @@
 #! /usr/bin/python
 # -*- coding: UTF-8 -*-
 
-#  Copyright 2013-2018 Luiko Czub, TestLink-API-Python-client developers
+#  Copyright 2013-2019 Luiko Czub, TestLink-API-Python-client developers
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -245,7 +245,7 @@ def test_uploadTestSuiteAttachment_unknownID(api_client, attachmentFile):
  
 def test_uploadTestCaseAttachment_unknownID(api_client, attachmentFile):
     with pytest.raises(TLResponseError, match='5000.*testcaseid'):
-        api_client.uploadTestCaseAttachment(attachmentFile, 40000712, 
+        api_client.uploadTestCaseAttachment(attachmentFile, 40000712, 1,
                     title='title 40000713', description='descr. 40000714')
  
 def test_uploadAttachment_unknownID(api_client, attachmentFile):
@@ -254,7 +254,7 @@ def test_uploadAttachment_unknownID(api_client, attachmentFile):
                     title='title 40000713', description='descr. 40000714')
  
 def test_testLinkVersion(api_client):
-    assert re.match('\d*\.\d*\.\d*', api_client.testLinkVersion() )
+    assert re.match(r'\d*\.\d*\.\d*', api_client.testLinkVersion() )
  
 def test_getUserByLogin_unknownKey(api_client):
     with pytest.raises(TLResponseError, match='10000.*User Login'):
